import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.DoubleWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Job;
import org.apache.hadoop.mapreduce.lib.input.FileInputFormat;
import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;

public class Main {
    public static void main(String[] args) throws Exception {

        if (args.length < 2) {
            System.err.println("Usage: Main <input path> <output path>");
            System.exit(-1);
        }

        String inputPath = args[0];
        String outputPathBase = args[1];

        runMonthlyResidentialPowerJob(inputPath, outputPathBase + "/monthly_residential");
        runAnnualIndustrialPowerJob(inputPath, outputPathBase + "/annual_industrial");
        runProvinceMaxDailyPowerJob(inputPath, outputPathBase + "/province_max_daily");
    }

    private static void runMonthlyResidentialPowerJob(String inputPath, String outputPath) throws Exception {
        Configuration conf = new Configuration();
        Job job = Job.getInstance(conf, "Monthly Residential Power Usage");
        job.setJarByClass(Main.class);
        job.setMapperClass(MonthlyResidentialPowerMapper.class);
        job.setReducerClass(MonthlyResidentialPowerReducer.class);
        job.setOutputKeyClass(Text.class);
        job.setOutputValueClass(DoubleWritable.class);
        FileInputFormat.addInputPath(job, new Path(inputPath));
        FileOutputFormat.setOutputPath(job, new Path(outputPath));
        job.waitForCompletion(true);
    }

    private static void runAnnualIndustrialPowerJob(String inputPath, String outputPath) throws Exception {
        Configuration conf = new Configuration();
        Job job = Job.getInstance(conf, "Annual Industrial Power Usage");
        job.setJarByClass(Main.class);
        job.setMapperClass(AnnualIndustrialPowerMapper.class);
        job.setReducerClass(AnnualIndustrialPowerReducer.class);
        job.setOutputKeyClass(Text.class);
        job.setOutputValueClass(DoubleWritable.class);
        FileInputFormat.addInputPath(job, new Path(inputPath));
        FileOutputFormat.setOutputPath(job, new Path(outputPath));
        job.waitForCompletion(true);
    }

    private static void runProvinceMaxDailyPowerJob(String inputPath, String outputPath) throws Exception {
        Configuration conf = new Configuration();
        Job job = Job.getInstance(conf, "Province Max Daily Power Usage");
        job.setJarByClass(Main.class);
        job.setMapperClass(ProvinceMaxDailyPowerMapper.class);
        job.setReducerClass(ProvinceMaxDailyPowerReducer.class);
        job.setOutputKeyClass(Text.class);
        job.setOutputValueClass(Text.class);
        FileInputFormat.addInputPath(job, new Path(inputPath));
        FileOutputFormat.setOutputPath(job, new Path(outputPath));
        job.waitForCompletion(true);
    }
}
